@@ -210,13 +210,13 @@ if __name__ == '__main__':
 	optimum = query.get_minimum_of_repairs(net_with_data, repair_options)
 	print 'done.'
 	    
-	print '   The data set can be repaired with minimal', optimum[0],'operations.'
+	print '   The data set can be repaired with minimal', optimum.score[0],'operations.'
 	  
 	do_repair= raw_input('\nDo you want to compute all possible repair sets? Y/n:')
 	if do_repair=="Y":
 
-	  print '\nComputing all repair sets with size', optimum[0],'...',
-	  models = query.get_minimal_repair_sets(net_with_data, repair_options, optimum[0])
+	  print '\nComputing all repair sets with size', optimum.score[0],'...',
+	  models = query.get_minimal_repair_sets(net_with_data, repair_options, optimum.score[0])
 	  print "done."
 	  count = 1
 	  oldmodel = 0
@@ -232,8 +232,8 @@ if __name__ == '__main__':
 	#print 'Computing subset minimal repairs ...'
 	#print '\n', query.subset_minimal_repair_flip_obs(net_with_data)
 	
-	print '\nComputing predictions that hold under all repair sets size', optimum[0],'...',
-	model = query.get_predictions_under_minimal_repair(net_with_data, repair_options, optimum[0])
+	print '\nComputing predictions that hold under all repair sets size', optimum.score[0],'...',
+	model = query.get_predictions_under_minimal_repair(net_with_data, repair_options, optimum.score[0])
 	print "done."
 	predictions = model.to_list()
 	#predictions.sort()
