@@ -46,7 +46,7 @@ class Lexer:
 	t_COM = r','
 
 	def __init__(self):
-		import bioasp.ply.lex as lex
+		import pyasp.ply.lex as lex
 		self.lexer = lex.lex(object = self, optimize=1, lextab='graph_parser_lextab')
 
 	# Ignored characters
@@ -77,7 +77,7 @@ class Parser:
 		self.args = []
 		self.commas = []
 		self.lexer = Lexer()
-		import bioasp.ply.yacc as yacc
+		import pyasp.ply.yacc as yacc
 		#self.parser = yacc.yacc(module=self, debug=False, tabmodule='calc_parsetab', debugfile="calc_parser.out")
 		self.parser = yacc.yacc(module=self, optimize=1, tabmodule='graph_parser_parsetab',)
 
